==> org.eclipse.cdt.managedbuilder.core.source_7.0.2.201102110609.jar: org/eclipse/cdt/managedbuilder/internal/core/HeadlessBuildMessages.java <==
/*******************************************************************************
 * Copyright (c) 2009, 2010 Broadcom Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Broadcom Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.cdt.managedbuilder.internal.core;

import org.eclipse.osgi.util.NLS;

public class HeadlessBuildMessages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.cdt.managedbuilder.internal.core.PluginResources"; //$NON-NLS-1$
	public static String HeadlessBuilder_already_exists_in_workspace;
	public static String HeadlessBuilder_build_failed;
	public static String HeadlessBuilder_building_all;
	public static String HeadlessBuilder_cant_be_found;
	public static String HeadlessBuilder_clean_failed;
	public static String HeadlessBuilder_cleaning_all_projects;
	public static String HeadlessBuilder_CouldntLockWorkspace;
	public static String HeadlessBuilder_Directory;
	public static String HeadlessBuilder_Error;
	public static String HeadlessBuilder_importAll;
	public static String HeadlessBuilder_invalid_argument;
	public static String HeadlessBuilder_is_not_accessible;
	public static String HeadlessBuilder_is_not_valid_in_workspace;
	public static String HeadlessBuilder_MustSpecifyWorkspace;
	public static String HeadlessBuilder_no_arguments;
	public static String HeadlessBuilder_NoConfigMatched;
	public static String HeadlessBuilder_NoProjectMatched;
	public static String HeadlessBuilder_Not_CDT_Proj;
	public static String HeadlessBuilder_project;
	public static String HeadlessBuilder_Quote;
	public static String HeadlessBuilder_RegExSyntaxError;
	public static String HeadlessBuilder_Skipping;
	public static String HeadlessBuilder_Skipping2;
	public static String HeadlessBuilder_unknown_argument;
	public static String HeadlessBuilder_URI;
	public static String HeadlessBuilder_usage;
	public static String HeadlessBuilder_usage_build;
	public static String HeadlessBuilder_usage_clean_build;
	public static String HeadlessBuilder_invalid_uri;
	public static String HeadlessBuilder_usage_import;
	public static String HeadlessBuilder_Workspace;
	public static String HeadlessBuilder_WorkspaceInUse;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, HeadlessBuildMessages.class);
	}

	private HeadlessBuildMessages() {
	}
}

==> org.eclipse.cdt.managedbuilder.core.source_8.3.0.201511021005.jar: org/eclipse/cdt/managedbuilder/internal/core/HeadlessBuildMessages.java <==
/*******************************************************************************
 * Copyright (c) 2009, 2014 Broadcom Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Broadcom Corporation - initial API and implementation
 *     R. Zulliger, C. Walther (Indel AG) - Bug 355609 Disable indexer
 *******************************************************************************/
package org.eclipse.cdt.managedbuilder.internal.core;

import org.eclipse.osgi.util.NLS;

public class HeadlessBuildMessages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.cdt.managedbuilder.internal.core.HeadlessBuildMessages"; //$NON-NLS-1$
	public static String HeadlessBuilder_already_exists_in_workspace;
	public static String HeadlessBuilder_build_failed;
	public static String HeadlessBuilder_building_all;
	public static String HeadlessBuilder_cant_be_found;
	public static String HeadlessBuilder_clean_failed;
	public static String HeadlessBuilder_cleaning_all_projects;
	public static String HeadlessBuilder_CouldntLockWorkspace;
	public static String HeadlessBuilder_Directory;
	public static String HeadlessBuilder_EnvVar_Append;
	public static String HeadlessBuilder_EnvVar_Prepend;
	public static String HeadlessBuilder_EnvVar_Remove;
	public static String HeadlessBuilder_EnvVar_Replace;
	public static String HeadlessBuilder_Error;
	public static String HeadlessBuilder_importAll;
	public static String HeadlessBuilder_IncludeFile;
	public static String HeadlessBuilder_InlucdePath;
	public static String HeadlessBuilder_invalid_argument;
	public static String HeadlessBuilder_is_not_accessible;
	public static String HeadlessBuilder_is_not_valid_in_workspace;
	public static String HeadlessBuilder_MustSpecifyWorkspace;
	public static String HeadlessBuilder_no_arguments;
	public static String HeadlessBuilder_NoConfigMatched;
	public static String HeadlessBuilder_NoProjectMatched;
	public static String HeadlessBuilder_Not_CDT_Proj;
	public static String HeadlessBuilder_project;
	public static String HeadlessBuilder_Quote;
	public static String HeadlessBuilder_RegExSyntaxError;
	public static String HeadlessBuilder_Skipping;
	public static String HeadlessBuilder_Skipping2;
	public static String HeadlessBuilder_ToolOption_Replace;
	public static String HeadlessBuilder_ToolOption_Append;
	public static String HeadlessBuilder_ToolOption_Prepend;
	public static String HeadlessBuilder_ToolOption_Remove;
	public static String HeadlessBuilder_ToolOption_Types;
	public static String HeadlessBuilder_unknown_argument;
	public static String HeadlessBuilder_URI;
	public static String HeadlessBuilder_usage;
	public static String HeadlessBuilder_usage_build;
	public static String HeadlessBuilder_usage_clean_build;
	public static String HeadlessBuilder_invalid_uri;
	public static String HeadlessBuilder_PreprocessorDefine;
	public static String HeadlessBuilder_usage_import;
	public static String HeadlessBuilder_usage_no_indexer;
	public static String HeadlessBuilder_Workspace;
	public static String HeadlessBuilder_WorkspaceInUse;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, HeadlessBuildMessages.class);
	}

	private HeadlessBuildMessages() {
	}
}
